local server = require('server/server')
local entity = require('entity')
local scenes = require('scenes')
local input = require('input')

function love.load()
    windowWidth = love.graphics.getWidth()
    windowHeight = love.graphics.getHeight()

    love.physics.setMeter(64)
    world = love.physics.newWorld(0, 9.81*64, true)

    floor = {}
    floor.body = love.physics.newBody(world, x, y, "static")
    floor.shape = love.physics.newRectangleShape(0, windowHeight-25, windowWidth*2, 50)
    floor.fixture = love.physics.newFixture(floor.body, floor.shape)

    --love.graphics.setDefaultFilter('nearest', 'nearest')

    hostBtnImg = love.graphics.newImage('sprites/host.png')
    joinBtnImg = love.graphics.newImage('sprites/join.png')
    quitBtnImg = love.graphics.newImage('sprites/quit.png')
    backBtnImg = love.graphics.newImage('sprites/back.png')

    blueSprite = love.graphics.newImage('sprites/blue.png')
    yellowSprite = love.graphics.newImage('sprites/yellow.png')
    redSprite = love.graphics.newImage('sprites/red.png')
    purpleSprite = love.graphics.newImage('sprites/purple.png')
end

  
function love.draw()
    love.graphics.setBackgroundColor(1, 1, 1)
    love.graphics.setColor(0, 0, 0)
    if server.isConnected() then
        love.graphics.print('A peer connected', love.math.newTransform(0, 0, 0, 3))
        for _, e in pairs(entity.entities) do
            entity.draw(e)
        end
        love.graphics.setColor(0.28, 0.63, 0.05)
        love.graphics.polygon("fill", floor.body:getWorldPoints(floor.shape:getPoints()))
    end

    love.graphics.setColor(0, 0, 0)
    if server.isServer() then
        love.graphics.print('You are the host.', love.math.newTransform(0, 50, 0, 3))
    end

    scenes.draw()
end
  
function love.update(dt)
    -- Check to see if a player has spawned and update its movement if any direction keys are being pressed
    if entity.id then
        local player = entity.entities[entity.id]
        local old_x = player.x
        local old_y = player.y
        entity.move()
        if player.x ~= old_x or player.x ~= old_y then
            server.send('move|' .. player.id .. '|' .. player.x .. '|' .. player.y)
        end
    end

    server.update()
    world:update(dt)
end
  
function love.quit()
    server.disconnect()
end

function love.mousepressed(x, y, button, istouch, presses)
    if button == 1 then
        scenes.update()
    end
end

love.keypressed = function(pressed_key)
    input[pressed_key] = true
end
  
love.keyreleased = function(released_key)
    input[released_key] = false
end